==> librepcb-0.1.7-source.zip: librepcb-0.1.7/img/README.md <==
# Images

This directory contains all images which are required in the LibrePCB application or other tools.

- Most images are from the "Open Icon Library": http://openiconlibrary.sourceforge.net/
- Some images are from https://www.iconfinder.com/
- Some images are from https://icons8.com/ (we may use those icons under the free license since we attribute icons8 in the about dialog)

The following files are from "Open Icon Library" (found in open_icon_library-full-0.11.tar.bz2 with fdupes),
with format `<filename> <filename in Open Icon Library> <license>`

```
actions/add.png icons/png/64x64/actions/edit-add-4.png LGPL-2.1
actions/apply.png icons/png/48x48/actions/dialog-accept.png LGPL-2.1
actions/bookmark.png icons/png/48x48/actions/bookmark-4.png LGPL-2.1
actions/cam_export.png icons/png/48x48/apps/gerbv.png GPLv3
actions/cancel.png icons/png/48x48/actions/dialog-cancel-4.png LGPL-2.1
actions/close.png icons/png/48x48/actions/application-exit-4.png CC-BY-SA 3.0 or LGPL
actions/copy.png icons/png/48x48/actions/edit-copy-6.png CC-BY-SA 3.0 or LGPL
actions/cut.png icons/png/48x48/actions/edit-cut-5.png LGPL-2.1
actions/delete.png icons/png/48x48/actions/edit-delete-2.png GPLv2
actions/down.png icons/png/48x48/actions/go-down-5.png PD
actions/download.png icons/png/48x48/actions/download-3.png CC-BY-SA 3.0 or LGPL
actions/draw_arc.png icons/png/48x48/actions/draw-halfcircle3.png CC-BY-SA 3.0 or LGPL
actions/draw_circle.png icons/png/32x32/actions/draw-circle-2.png CC-BY-SA 3.0 or LGPL
actions/draw_polygon.png icons/png/32x32/actions/draw-polyline-2.png CC-BY-SA 3.0 or LGPL
actions/draw_rectangle.png icons/png/48x48/actions/draw-rectangle-2.png CC-BY-SA 3.0 or LGPL
actions/edit.png icons/png/48x48/actions/edit-4.png LGPL-2.1
actions/export_svg.png icons/png/48x48/mimetypes/oxygen-style/image-svg+xml.png CC-BY-SA 3.0 or LGPL
actions/generate_bom.png icons/png/64x64/mimetypes/gnome-style/x-office-spreadsheet-2.png LGPL-2.1
actions/help.png icons/png/48x48/actions/help-2.png LGPL-2.1
actions/home.png icons/png/48x48/actions/go-home-4.png GPLv2
actions/info.png icons/png/48x48/actions/help-about-3.png CC-BY-SA 3.0 or LGPL
actions/mirror_horizontal.png icons/png/48x48/actions/object-flip-horizontal-2.png CC-BY-SA 3.0 or LGPL
actions/mirror_vertical.png icons/png/48x48/actions/object-flip-vertical-2.png CC-BY-SA 3.0 or LGPL
actions/move.png icons/png/48x48/actions/transform-move.png CC-BY-SA 3.0 or LGPL
actions/new_2.png icons/png/48x48/actions/document-new-3.png GPLv2
actions/new.png icons/png/48x48/actions/document-new-8.png LGPL-2.1
actions/open.png icons/png/48x48/actions/document-open-7.png CC-BY-SA 3.0 or LGPL
actions/paste.png icons/png/48x48/actions/edit-paste-3.png GPLv2
actions/pdf.png icons/png/48x48/mimetypes/oxygen-style/application-pdf.png CC-BY-SA 3.0 or LGPL
actions/plus_2.png icons/png/48x48/actions/edit-add-4.png LGPL-2.1
actions/plus.png icons/png/48x48/actions/dialog-more.png GPLv2
actions/print_preview.png icons/png/48x48/actions/document-print-preview-4.png LGPL-2.1
actions/print.png icons/png/48x48/actions/document-print-5.png CC-BY-SA 3.0 or LGPL
actions/quit.png icons/png/48x48/actions/system-exit.png GPLv2
actions/recent.png icons/png/48x48/status/appointment-soon.png GPLv2
actions/redo.png icons/png/48x48/actions/edit-redo-3.png GPLv2
actions/refresh.png icons/png/48x48/actions/view-refresh-7.png CC-BY-SA 3.0 or LGPL
actions/rotate_left.png icons/png/48x48/actions/object-rotate-left-3.png CC-BY-SA 3.0 or LGPL
actions/rotate_right.png icons/png/48x48/actions/object-rotate-right-3.png CC-BY-SA 3.0 or LGPL
actions/save.png icons/png/48x48/actions/document-save-2.png GPLv2
actions/search.png icons/png/64x64/actions/edit-find-5.png LGPL-2.1
actions/select_all.png icons/png/64x64/actions/edit-select-all-2.png PD
actions/select_rect.png icons/png/48x48/actions/select-rectangular.png CC-BY-SA 3.0 or LGPL
actions/settings.png icons/png/48x48/actions/configure-2.png LGPL-2.1
actions/stop.png icons/png/48x48/actions/process-stop.png GPLv2
actions/up.png icons/png/48x48/actions/go-up-5.png PD
actions/working.png icons/png/48x48/symbols/pictograms-road_signs-workman_ahead_roadsign.png PD
actions/zoom_all.png icons/png/48x48/actions/zoom-fit-best-2.png GPLv2
actions/zoom_in.png icons/png/48x48/actions/zoom-in-3.png GPLv2
actions/zoom_out.png icons/png/48x48/actions/zoom-out-3.png GPLv2
command_toolbars/align_horizontal_center.png icons/png/48x48/actions/align-horizontal-center-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_horizontal_left.png icons/png/48x48/actions/align-horizontal-left.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_horizontal_right.png icons/png/48x48/actions/align-horizontal-right-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_bottom.png icons/png/48x48/actions/align-vertical-bottom-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_center.png icons/png/48x48/actions/align-vertical-center-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_top.png icons/png/48x48/actions/align-vertical-top-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/cancel.png icons/png/48x48/actions/dialog-cancel-4.png PD
status/success.png icons/png/48x48/actions/dialog-accept.png PD
```

Copied from "Open Icon Library" and modified:

```
actions/bookmark_gray.png copied from actions/bookmark.png LGPL-2.1
library/package.png copied from library/device.png
places/folder_gray.png copied from places/folder.png
places/folder_green.png copied from places/folder.png
places/folder_open_gray.png copied from places/folder_open.png
places/folder_open_green.png copied from places/folder_open.png
places/project_folder.png copied from places/folder.png
```

From Icons8:

```
actions/clone.png: Color → Science → Natural Sciences → Clone
actions/drc.png: Color → Programming → Testing → Pass Fail
actions/export.png: Color → Data → Export
actions/export_pick_place_file.png: Office L → Industry → Production Process→ Assembly Line
actions/export_pixmap: Color → Photo and Video → Photos → Image
actions/flip_horizontal.png: Justicon Lineal Color → Graphic Design → Flip
actions/flip_vertical.png: Justicon Lineal Color → Graphic Design → Flip
actions/import.png: Color → Data → Managing Data → Import
actions/move_to.png: Pastel → Arrows → Move Out
actions/order_pcb.png: Color → Ecommerce → Buy and Sell → Buy
actions/ruler.png: Color → Editing → Image Editing → Ruler
```

From [publicdomainvectors.org](https://publicdomainvectors.org/):

```
wizards/eagle_watermark.png: "Eagle in flight" (manually modified) CC0-1.0
```

Created by LibrePCB developers, released under CC0-1.0:

```
actions/add_hole.png
actions/add_name.png
actions/add_plane.png
actions/add_smt_pad.png
actions/add_symbol_pin.png
actions/add_text.png
actions/add_tht_pad.png
actions/add_value.png
actions/add_via.png
actions/board_editor.png
actions/draw_line.png
actions/draw_netlabel.png
actions/draw_wire.png
actions/grid.png
actions/hide_planes.png
actions/layers.png
actions/rebuild_plane.png
actions/schematic.png
actions/show_planes.png
command_toolbars/pad_bottom.png
command_toolbars/pad_tht.png
command_toolbars/pad_top.png
command_toolbars/shape_octagon.png
command_toolbars/shape_rect.png
command_toolbars/shape_round.png
command_toolbars/via_octagon.png
command_toolbars/via_round.png
command_toolbars/via_square.png
command_toolbars/wire_45_90.png
command_toolbars/wire_90_45.png
command_toolbars/wire_h_v.png
command_toolbars/wire_straight.png
command_toolbars/wire_v_h.png
empty.png
library/bipolar_capacitor_eu.png
library/bipolar_capacitor_us.png
library/footprint.png
library/gnd.png
library/inductor_eu.png
library/inductor_us.png
library/resistor_eu.png
library/resistor_us.png
library/symbol.png
library/unipolar_capacitor_eu.png
library/unipolar_capacitor_us.png
library/vcc.png
norm/iec_60617.png
norm/ieee_315.png
wizards/watermark.jpg
```

Created for LibrePCB by a 99designs designer:

```
app/librepcb.icns
app/librepcb.ico
app/librepcb.png
app/librepcb.svg
logo/32x32.png
logo/48x48.png
logo/64x64.png
```

==> librepcb-1.0.0-source.zip: librepcb-1.0.0/img/README.md <==
# Images

This directory contains all images which are required in the LibrePCB application or other tools.

- Most images are from the "Open Icon Library": http://openiconlibrary.sourceforge.net/
- Some images are from https://www.iconfinder.com/
- Some images are from https://icons8.com/ (we may use those icons under the free license since we attribute icons8 in the about dialog)

The following files are from "Open Icon Library" (found in open_icon_library-full-0.11.tar.bz2 with fdupes),
with format `<filename> <filename in Open Icon Library> <license>`

```
actions/add.png icons/png/64x64/actions/edit-add-4.png LGPL-2.1
actions/apply.png icons/png/48x48/actions/dialog-accept.png LGPL-2.1
actions/bookmark.png icons/png/48x48/actions/bookmark-4.png LGPL-2.1
actions/cam_export.png icons/png/48x48/apps/gerbv.png GPLv3
actions/cancel.png icons/png/48x48/actions/dialog-cancel-4.png LGPL-2.1
actions/clean.png icons/png/48x48/actions/edit-clear-3.png PD
actions/close.png icons/png/48x48/actions/application-exit-4.png CC-BY-SA 3.0 or LGPL
actions/copy.png icons/png/48x48/actions/edit-copy-6.png CC-BY-SA 3.0 or LGPL
actions/cut.png icons/png/48x48/actions/edit-cut-5.png LGPL-2.1
actions/delete.png icons/png/48x48/actions/edit-delete-2.png GPLv2
actions/down.png icons/png/48x48/actions/go-down-5.png PD
actions/download.png icons/png/48x48/actions/download-3.png CC-BY-SA 3.0 or LGPL
actions/draw_arc.png icons/png/48x48/actions/draw-halfcircle3.png CC-BY-SA 3.0 or LGPL
actions/draw_circle.png icons/png/32x32/actions/draw-circle-2.png CC-BY-SA 3.0 or LGPL
actions/draw_polygon.png icons/png/32x32/actions/draw-polyline-2.png CC-BY-SA 3.0 or LGPL
actions/draw_rectangle.png icons/png/48x48/actions/draw-rectangle-2.png CC-BY-SA 3.0 or LGPL
actions/edit.png icons/png/48x48/actions/edit-4.png LGPL-2.1
actions/export_step.png icons/png/48x48/mimetypes/oxygen-style/text-x-moc.png LGPL-2.1
actions/export_svg.png icons/png/48x48/mimetypes/oxygen-style/image-svg+xml.png CC-BY-SA 3.0 or LGPL
actions/generate_bom.png icons/png/64x64/mimetypes/gnome-style/x-office-spreadsheet-2.png LGPL-2.1
actions/help.png icons/png/48x48/actions/help-2.png LGPL-2.1
actions/home.png icons/png/48x48/actions/go-home-4.png GPLv2
actions/info.png icons/png/48x48/actions/help-about-3.png CC-BY-SA 3.0 or LGPL
actions/mirror_horizontal.png icons/png/48x48/actions/object-flip-horizontal-2.png CC-BY-SA 3.0 or LGPL
actions/mirror_vertical.png icons/png/48x48/actions/object-flip-vertical-2.png CC-BY-SA 3.0 or LGPL
actions/move.png icons/png/48x48/actions/transform-move.png CC-BY-SA 3.0 or LGPL
actions/new_2.png icons/png/48x48/actions/document-new-3.png GPLv2
actions/new.png icons/png/48x48/actions/document-new-8.png LGPL-2.1
actions/open.png icons/png/48x48/actions/document-open-7.png CC-BY-SA 3.0 or LGPL
actions/output_jobs.png icons/png/48x48/actions/system-run-3.png GPLv2
actions/paste.png icons/png/48x48/actions/edit-paste-3.png GPLv2
actions/pdf.png icons/png/48x48/mimetypes/oxygen-style/application-pdf.png CC-BY-SA 3.0 or LGPL
actions/plus_2.png icons/png/48x48/actions/edit-add-4.png LGPL-2.1
actions/plus.png icons/png/48x48/actions/dialog-more.png GPLv2
actions/print_preview.png icons/png/48x48/actions/document-print-preview-4.png LGPL-2.1
actions/print.png icons/png/48x48/actions/document-print-5.png CC-BY-SA 3.0 or LGPL
actions/quick_check.png icons/png/48x48/actions/quickopen.png CC-BY-SA 3.0 or LGPL
actions/quit.png icons/png/48x48/actions/system-exit.png GPLv2
actions/recent.png icons/png/48x48/status/appointment-soon.png GPLv2
actions/redo.png icons/png/48x48/actions/edit-redo-3.png GPLv2
actions/refresh.png icons/png/48x48/actions/view-refresh-7.png CC-BY-SA 3.0 or LGPL
actions/rotate_left.png icons/png/48x48/actions/object-rotate-left-3.png CC-BY-SA 3.0 or LGPL
actions/rotate_right.png icons/png/48x48/actions/object-rotate-right-3.png CC-BY-SA 3.0 or LGPL
actions/run.png icons/png/48x48/actions/arrow-right-3.png CC-BY-SA 3.0 or LGPL
actions/run_all.png icons/png/48x48/actions/arrow-right-double-3.png CC-BY-SA 3.0 or LGPL
actions/save.png icons/png/48x48/actions/document-save-2.png GPLv2
actions/search.png icons/png/64x64/actions/edit-find-5.png LGPL-2.1
actions/select_all.png icons/png/64x64/actions/edit-select-all-2.png PD
actions/select_rect.png icons/png/48x48/actions/select-rectangular.png CC-BY-SA 3.0 or LGPL
actions/settings.png icons/png/48x48/actions/configure-2.png LGPL-2.1
actions/stop.png icons/png/48x48/actions/process-stop.png GPLv2
actions/up.png icons/png/48x48/actions/go-up-5.png PD
actions/wizard.png icons/png/48x48/actions/tools-wizard-3.png CC-BY-SA 3.0 or LGPL
actions/working.png icons/png/48x48/symbols/pictograms-road_signs-workman_ahead_roadsign.png PD
actions/zoom_all.png icons/png/48x48/actions/zoom-fit-best-2.png GPLv2
actions/zoom_in.png icons/png/48x48/actions/zoom-in-3.png GPLv2
actions/zoom_out.png icons/png/48x48/actions/zoom-out-3.png GPLv2
command_toolbars/align_horizontal_center.png icons/png/48x48/actions/align-horizontal-center-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_horizontal_left.png icons/png/48x48/actions/align-horizontal-left.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_horizontal_right.png icons/png/48x48/actions/align-horizontal-right-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_bottom.png icons/png/48x48/actions/align-vertical-bottom-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_center.png icons/png/48x48/actions/align-vertical-center-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/align_vertical_top.png icons/png/48x48/actions/align-vertical-top-2.png CC-BY-SA 3.0 or LGPL
command_toolbars/cancel.png icons/png/48x48/actions/dialog-cancel-4.png PD
status/locked.png icons/png/48x48/status/object-locked-2.png CC-BY-SA 3.0 or LGPL
status/success.png icons/png/48x48/actions/dialog-accept.png PD
status/unlocked.png icons/png/48x48/status/object-unlocked-2.png CC-BY-SA 3.0 or LGPL
```

Copied from "Open Icon Library" and modified:

```
actions/bookmark_gray.png copied from actions/bookmark.png LGPL-2.1
library/package.png copied from library/device.png
places/folder_gray.png copied from places/folder.png
places/folder_green.png copied from places/folder.png
places/folder_open_gray.png copied from places/folder_open.png
places/folder_open_green.png copied from places/folder_open.png
places/project_folder.png copied from places/folder.png
```

From Icons8:

```
actions/clone.png: Color → Science → Natural Sciences → Clone
actions/drc.png: Color → Programming → Testing → Pass Fail
actions/export.png: Color → Data → Export
actions/export_pick_place_file.png: Office L → Industry → Production Process→ Assembly Line
actions/export_pixmap: Color → Photo and Video → Photos → Image
actions/flip_horizontal.png: Justicon Lineal Color → Graphic Design → Flip
actions/flip_vertical.png: Justicon Lineal Color → Graphic Design → Flip
actions/import.png: Color → Data → Managing Data → Import
actions/move_to.png: Pastel → Arrows → Move Out
actions/order_pcb.png: Color → Ecommerce → Buy and Sell → Buy
actions/ruler.png: Color → Editing → Image Editing → Ruler
actions/view_3d.png: Windows 11 Color → Editing → 3D Objects
library/part.png: Color → Ecommerce → Buy and Sell → Buy
```

From [publicdomainvectors.org](https://publicdomainvectors.org/):

```
wizards/eagle_watermark.png: "Eagle in flight" (manually modified) CC0-1.0
```

Created by LibrePCB developers, released under CC0-1.0:

```
actions/add_hole.png
actions/add_name.png
actions/add_plane.png
actions/add_smt_pad.png
actions/add_symbol_pin.png
actions/add_text.png
actions/add_tht_pad.png
actions/add_value.png
actions/add_via.png
actions/board_editor.png
actions/draw_line.png
actions/draw_netlabel.png
actions/draw_wire.png
actions/grid.png
actions/hide_planes.png
actions/layers.png
actions/rebuild_plane.png
actions/schematic.png
actions/show_pin_numbers.png
actions/show_planes.png
command_toolbars/pad_bottom.png
command_toolbars/pad_tht.png
command_toolbars/pad_top.png
command_toolbars/shape_octagon.png
command_toolbars/shape_rect.png
command_toolbars/shape_round.png
command_toolbars/via_octagon.png
command_toolbars/via_round.png
command_toolbars/via_square.png
command_toolbars/wire_45_90.png
command_toolbars/wire_90_45.png
command_toolbars/wire_h_v.png
command_toolbars/wire_straight.png
command_toolbars/wire_v_h.png
empty.png
library/bipolar_capacitor_eu.png
library/bipolar_capacitor_us.png
library/footprint.png
library/gnd.png
library/inductor_eu.png
library/inductor_us.png
library/resistor_eu.png
library/resistor_us.png
library/symbol.png
library/unipolar_capacitor_eu.png
library/unipolar_capacitor_us.png
library/vcc.png
norm/iec_60617.png
norm/ieee_315.png
wizards/watermark.jpg
```

Created for LibrePCB by a 99designs designer:

```
app/librepcb.icns
app/librepcb.ico
app/librepcb.png
app/librepcb.svg
logo/32x32.png
logo/48x48.png
logo/64x64.png
```
